-- Create database (if not exists)
CREATE DATABASE IF NOT EXISTS evaluation_system;
USE evaluation_system;

-- USERS TABLE
CREATE TABLE users (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    email VARCHAR(100) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    role ENUM('staff', 'team_lead', 'hr', 'director', 'admin') NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- EVALUATIONS TABLE
CREATE TABLE evaluations (
    id INT AUTO_INCREMENT PRIMARY KEY,
    staff_id INT NOT NULL,

    -- Staff Self-Evaluation
    quality_of_work INT,
    productivity INT,
    deadlines INT,
    accomplishments TEXT,
    improvements TEXT,
    career_goals TEXT,

    -- Team Lead Evaluation
    team_collab INT,
    problem_solving INT,
    strengths TEXT,
    weaknesses TEXT,
    promotion VARCHAR(20),

    -- HR Evaluation
    policy INT,
    punctuality INT,
    discipline TEXT,
    retention VARCHAR(20),

    -- Director Final Review
    leadership VARCHAR(50),
    future_role TEXT,
    final_grade ENUM('A','B','C','D','F'),

    -- Meta
    status ENUM('submitted','reviewed_by_team_lead','reviewed_by_hr','completed') DEFAULT 'submitted',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    FOREIGN KEY (staff_id) REFERENCES users(id) ON DELETE CASCADE
);

-- NOTIFICATIONS TABLE (optional)
CREATE TABLE notifications (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT NOT NULL,
    message TEXT NOT NULL,
    read_status TINYINT(1) DEFAULT 0,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
);
