<?php

/**
 * Sanitize form input to prevent XSS and SQL injection.
 */
function sanitizeInput($data) {
    return htmlspecialchars(trim($data), ENT_QUOTES, 'UTF-8');
}

/**
 * Format any date string to a readable format.
 */
function formatDate($date) {
    return date('F j, Y', strtotime($date));
}

/**
 * Log evaluation actions across stages (team_lead, hr, director).
 */
function logEvaluationAction($pdo, $evaluation_id, $stage, $action, $comment, $updated_by) {
    $stmt = $pdo->prepare("INSERT INTO evaluation_logs (evaluation_id, stage, action, comment, updated_by) VALUES (?, ?, ?, ?, ?)");
    $stmt->execute([$evaluation_id, $stage, $action, $comment, $updated_by]);
}

/**
 * Redirect by role to appropriate dashboard.
 */
function getDashboardRedirect($role) {
    switch ($role) {
        case 'admin': return 'views/dashboard/admin.php';
        case 'staff': return 'views/dashboard/staff.php';
        case 'team_lead': return 'views/dashboard/team_lead.php';
        case 'hr': return 'views/dashboard/hr.php';
        case 'director': return 'views/dashboard/director.php';
        default: return 'views/auth/login.php?error=role';
    }
}

/**
 * Email sender using Mailer class.
 */
function sendEmail($to, $subject, $message) {
    require_once __DIR__ . '/../mail/Mailer.php';
    return Mailer::send($to, $subject, $message);
}
