<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../templates/header.php';

// Load sidebar dynamically
$role = $_SESSION['user']['role'];
if ($role === 'admin') {
    require_once '../../templates/sidebar/admin.php';
} elseif ($role === 'hr') {
    require_once '../../templates/sidebar/hr.php';
} else {
    echo "<div class='alert alert-danger'>Access Denied</div>";
    require_once '../../templates/footer.php';
    exit;
}

// Fetch evaluation logs
$stmt = $pdo->prepare("
    SELECT
        l.*,
        u.name AS evaluator_name,
        e.staff_id,
        s.name AS staff_name,
        s.email AS staff_email
    FROM evaluation_logs l
    JOIN users u ON l.updated_by = u.id
    JOIN evaluations e ON l.evaluation_id = e.id
    JOIN users s ON e.staff_id = s.id
    ORDER BY l.created_at DESC
");
$stmt->execute();
$logs = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<div class="container-fluid">
    <div class="row">
        <div class="col ms-3 p-4">
            <h4 class="mb-4"><?= $role === 'admin' ? 'Evaluation Logs (All Staff)' : 'Evaluation History' ?></h4>

            <?php if (empty($logs)): ?>
                <div class="alert alert-info">No evaluation activity has been recorded yet.</div>
            <?php else: ?>
                <div class="card shadow-sm">
                    <div class="card-body table-responsive">
                        <table class="table table-bordered table-striped align-middle">
                            <thead class="table-light">
                                <tr>
                                    <th>Staff Name</th>
                                    <th>Email</th>
                                    <th>Stage</th>
                                    <th>Action</th>
                                    <th>Comment</th>
                                    <th>Evaluator</th>
                                    <th>Date & Time</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($logs as $log): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($log['staff_name']) ?></td>
                                        <td><?= htmlspecialchars($log['staff_email']) ?></td>
                                        <td><?= ucfirst($log['stage']) ?></td>
                                        <td><span class="badge bg-primary"><?= ucfirst($log['action']) ?></span></td>
                                        <td><?= !empty($log['comment']) ? htmlspecialchars($log['comment']) : '<em>No comment</em>' ?></td>
                                        <td><?= htmlspecialchars($log['evaluator_name']) ?></td>
                                        <td><?= date('M d, Y h:i A', strtotime($log['created_at'])) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
