<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/director.php';

if (!isset($_GET['eval_id'])) {
    echo "<div class='alert alert-danger m-4'>No evaluation selected.</div>";
    require_once '../../templates/footer.php';
    exit;
}

$eval_id = $_GET['eval_id'];

$stmt = $pdo->prepare("
    SELECT e.*, u.name AS staff_name
    FROM evaluations e
    JOIN users u ON e.staff_id = u.id
    WHERE e.id = ?
");
$stmt->execute([$eval_id]);
$evaluation = $stmt->fetch();

// Handle grading
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $final_grade = $_POST['final_grade'];
    $director_comment = trim($_POST['director_comment']);

    $stmt = $pdo->prepare("
        UPDATE evaluations
        SET director_comments = ?, director_status = 'completed', final_grade = ?, updated_at = NOW()
        WHERE id = ?
    ");
    $stmt->execute([$director_comment, $final_grade, $eval_id]);

    logEvaluationAction(
        $pdo,
        $eval_id,
        'director',
        'graded',
        "Final grade: $final_grade. $director_comment",
        $_SESSION['user']['id']
    );

    echo "<div class='alert alert-success m-4'>✅ Final grade submitted.</div>";
}
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">🎓 Final Evaluation: <?= htmlspecialchars($evaluation['staff_name']) ?></h3>

        <div class="card mb-4">
            <div class="card-header bg-light fw-bold">HR Comments</div>
            <div class="card-body">
                <p><?= nl2br(htmlspecialchars($evaluation['hr_comments'])) ?></p>
            </div>
        </div>

        <?php if ($evaluation['director_status'] === 'pending'): ?>
            <form method="POST" class="card p-4 shadow-sm border">
                <div class="mb-3">
                    <label class="form-label">💬 Final Comment</label>
                    <textarea name="director_comment" class="form-control" rows="4" required></textarea>
                </div>

                <div class="mb-3">
                    <label class="form-label">🎯 Final Grade</label>
                    <select name="final_grade" class="form-select" required>
                        <option value="">-- Select Grade --</option>
                        <option>A</option>
                        <option>B</option>
                        <option>C</option>
                        <option>D</option>
                        <option>F</option>
                    </select>
                </div>

                <button type="submit" class="btn btn-success">
                    <i class="bi bi-check2-circle"></i> Submit Final Grade
                </button>
            </form>
        <?php else: ?>
            <div class="alert alert-info">✅ Final evaluation already completed.</div>
            <div class="card p-3">
                <h6 class="text-muted">Final Grade:</h6>
                <p><strong><?= $evaluation['final_grade'] ?></strong></p>

                <h6 class="text-muted mt-3">Director’s Comments:</h6>
                <p><?= nl2br(htmlspecialchars($evaluation['director_comments'])) ?></p>
            </div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
