<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';

// Load sidebar based on role
switch ($_SESSION['user']['role']) {
    case 'admin':
        require_once '../../templates/sidebar/admin.php';
        break;
    case 'hr':
        require_once '../../templates/sidebar/hr.php';
        break;
    case 'team_lead':
        require_once '../../templates/sidebar/team_lead.php';
        break;
    case 'staff':
        require_once '../../templates/sidebar/staff.php';
        break;
    case 'director':
        require_once '../../templates/sidebar/director.php';
        break;
}

// Fetch logs
$sql = "
    SELECT l.*,
           u.name AS updated_by_name,
           ev.staff_id,
           su.name AS staff_name
    FROM evaluation_logs l
    JOIN users u ON l.updated_by = u.id
    JOIN evaluations ev ON l.evaluation_id = ev.id
    JOIN users su ON ev.staff_id = su.id
    ORDER BY l.created_at DESC
";
$stmt = $pdo->prepare($sql);
$stmt->execute();
$logs = $stmt->fetchAll();
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">📜 Evaluation Logs History</h3>

        <?php if (count($logs) > 0): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped">
                    <thead class="table-dark">
                        <tr>
                            <th>Staff</th>
                            <th>Stage</th>
                            <th>Action</th>
                            <th>Comment</th>
                            <th>Updated By</th>
                            <th>Timestamp</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($logs as $log): ?>
                            <tr>
                                <td><?= htmlspecialchars($log['staff_name']) ?></td>
                                <td><?= ucfirst($log['stage']) ?></td>
                                <td><?= ucfirst($log['action']) ?></td>
                                <td><?= nl2br(htmlspecialchars($log['comment'])) ?></td>
                                <td><?= htmlspecialchars($log['updated_by_name']) ?></td>
                                <td><?= formatDate($log['created_at']) ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-info">No evaluation logs available.</div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
