<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/hr.php';

if (!isset($_GET['eval_id'])) {
    echo "<div class='alert alert-danger m-4'>No evaluation selected.</div>";
    require_once '../../templates/footer.php';
    exit;
}

$eval_id = $_GET['eval_id'];

// Fetch evaluation record
$stmt = $pdo->prepare("
    SELECT e.*, u.name AS staff_name
    FROM evaluations e
    JOIN users u ON e.staff_id = u.id
    WHERE e.id = ?
");
$stmt->execute([$eval_id]);
$evaluation = $stmt->fetch();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $hr_comments = trim($_POST['hr_comments']);

    $update = $pdo->prepare("UPDATE evaluations SET hr_comments = ?, hr_status = 'completed', updated_at = NOW() WHERE id = ?");
    $update->execute([$hr_comments, $eval_id]);

    logEvaluationAction($pdo, $eval_id, 'hr', 'reviewed', $hr_comments, $_SESSION['user']['id']);

    echo "<div class='alert alert-success m-4'>✅ HR review completed successfully.</div>";
}
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">📋 HR Review: <?= htmlspecialchars($evaluation['staff_name']) ?></h3>

        <div class="card mb-4">
            <div class="card-header bg-light fw-bold">Team Lead Comments</div>
            <div class="card-body">
                <p><?= nl2br(htmlspecialchars($evaluation['team_lead_comments'])) ?></p>
            </div>
        </div>

        <?php if ($evaluation['hr_status'] === 'pending'): ?>
            <form method="POST" class="card p-4 shadow-sm border">
                <h5 class="mb-3">💬 Your Comments</h5>
                <div class="mb-3">
                    <textarea name="hr_comments" class="form-control" rows="5" required></textarea>
                </div>
                <button type="submit" class="btn btn-success">
                    <i class="bi bi-check-circle"></i> Submit HR Review
                </button>
            </form>
        <?php else: ?>
            <div class="alert alert-info">✅ HR review already completed.</div>
            <div class="card p-3">
                <h6 class="text-muted">Previous HR Comments:</h6>
                <p><?= nl2br(htmlspecialchars($evaluation['hr_comments'])) ?></p>
            </div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
