<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/hr.php';

// Fetch completed evaluations with HR recommendations
$sql = "
    SELECT e.id AS evaluation_id, u.name AS staff_name, u.email, e.hr_comments, e.updated_at
    FROM evaluations e
    JOIN users u ON e.staff_id = u.id
    WHERE e.hr_status = 'completed' AND e.hr_comments IS NOT NULL
    ORDER BY e.updated_at DESC
";

$stmt = $pdo->prepare($sql);
$stmt->execute();
$recommendations = $stmt->fetchAll();
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">💡 HR Recommendations</h3>

        <?php if (count($recommendations) > 0): ?>
            <div class="table-responsive">
                <table class="table table-striped table-bordered">
                    <thead class="table-dark">
                        <tr>
                            <th>Staff Name</th>
                            <th>Email</th>
                            <th>HR Comments</th>
                            <th>Last Updated</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recommendations as $rec): ?>
                            <tr>
                                <td><?= htmlspecialchars($rec['staff_name']) ?></td>
                                <td><?= htmlspecialchars($rec['email']) ?></td>
                                <td><?= nl2br(htmlspecialchars($rec['hr_comments'])) ?></td>
                                <td><?= formatDate($rec['updated_at']) ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-warning">⚠️ No HR recommendations found.</div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
