<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/team_lead.php';

// Get team lead's ID
$team_lead_id = $_SESSION['user']['id'];

// Fetch pending evaluations submitted by staff under this team lead
$sql = "SELECT e.id AS evaluation_id, u.name AS staff_name, u.email, e.submitted_at
        FROM evaluations e
        JOIN users u ON e.staff_id = u.id
        WHERE e.team_lead_status = 'pending' AND u.team_lead_id = ?";

$stmt = $pdo->prepare($sql);
$stmt->execute([$team_lead_id]);
$pending = $stmt->fetchAll();
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">📋 Pending Staff Evaluations</h3>

        <?php if (count($pending) > 0): ?>
            <table class="table table-striped">
                <thead class="table-dark">
                    <tr>
                        <th>Staff Name</th>
                        <th>Email</th>
                        <th>Submitted On</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($pending as $row): ?>
                        <tr>
                            <td><?= htmlspecialchars($row['staff_name']) ?></td>
                            <td><?= htmlspecialchars($row['email']) ?></td>
                            <td><?= date('M j, Y', strtotime($row['submitted_at'])) ?></td>
                            <td>
                                <a href="team_lead_form.php?eval_id=<?= $row['evaluation_id'] ?>" class="btn btn-sm btn-primary">
                                    Evaluate
                                </a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">✅ No pending evaluations. You're all caught up!</div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
