<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/director.php';

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $eval_id = $_POST['eval_id'];
    $action = $_POST['recommendation'];
    $stmt = $pdo->prepare("UPDATE evaluations SET promotion_recommendation = ?, updated_at = NOW() WHERE id = ?");
    $stmt->execute([$action, $eval_id]);
    echo "<div class='alert alert-success m-4'>✅ Recommendation updated.</div>";
}

// Fetch evaluations already graded
$stmt = $pdo->prepare("
    SELECT e.id AS evaluation_id, u.name AS staff_name, u.email, e.final_grade, e.promotion_recommendation
    FROM evaluations e
    JOIN users u ON e.staff_id = u.id
    WHERE e.director_status = 'completed'
    ORDER BY e.updated_at DESC
");
$stmt->execute();
$records = $stmt->fetchAll();
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">🎯 Promotion & Reassignment Decisions</h3>

        <?php if (count($records) > 0): ?>
            <div class="table-responsive">
                <table class="table table-striped table-bordered align-middle">
                    <thead class="table-dark">
                        <tr>
                            <th>Staff</th>
                            <th>Email</th>
                            <th>Final Grade</th>
                            <th>Recommendation</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($records as $row): ?>
                            <tr>
                                <td><?= htmlspecialchars($row['staff_name']) ?></td>
                                <td><?= htmlspecialchars($row['email']) ?></td>
                                <td><strong><?= $row['final_grade'] ?></strong></td>
                                <td><?= ucfirst($row['promotion_recommendation']) ?></td>
                                <td>
                                    <form method="POST" class="d-flex gap-2">
                                        <input type="hidden" name="eval_id" value="<?= $row['evaluation_id'] ?>">
                                        <select name="recommendation" class="form-select form-select-sm" required>
                                            <option value="">-- Select --</option>
                                            <option value="promotion">Promotion</option>
                                            <option value="reassignment">Reassignment</option>
                                            <option value="none">None</option>
                                        </select>
                                        <button class="btn btn-sm btn-success">Save</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-info">No finalized evaluations found.</div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
