<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/staff.php';

// Handle submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $goals      = sanitizeInput($_POST['goals']);
    $challenges = sanitizeInput($_POST['challenges']);
    $skills     = sanitizeInput($_POST['skills']);
    $rating     = $_POST['rating'];

    $staff_id = $_SESSION['user']['id'];

    $stmt = $pdo->prepare("
        INSERT INTO evaluations (staff_id, goals, challenges, skills, rating, team_lead_status, hr_status, director_status, submitted_at, created_at, updated_at)
        VALUES (?, ?, ?, ?, ?, 'pending', 'pending', 'pending', NOW(), NOW(), NOW())
    ");
    $stmt->execute([$staff_id, $goals, $challenges, $skills, $rating]);

    $eval_id = $pdo->lastInsertId();

    // Log submission
    logEvaluationAction($pdo, $eval_id, 'staff', 'submitted', null, $staff_id);

    // Notify Team Lead (replace with real logic to fetch team lead email)
    require_once '../../mail/templates/to_team_lead.php';
    $teamLeadEmail = 'teamlead@example.com';
    $teamLeadName = 'Team Lead';
    $staffName = $_SESSION['user']['name'];

    sendEmail(
        $teamLeadEmail,
        "New Evaluation Submitted by $staffName",
        emailToTeamLead($staffName, $teamLeadName, $eval_id)
    );

    echo "<div class='alert alert-success m-4'>✅ Evaluation submitted and your team lead has been notified.</div>";
}
?>

<div class="container-fluid">
    <div class="row">
        <div class="col p-4">
            <h4 class="mb-4">Submit Self-Evaluation</h4>

            <form method="POST" class="card p-4 shadow-sm">
                <div class="mb-3">
                    <label class="form-label">Goals Achieved</label>
                    <textarea name="goals" class="form-control" rows="4" required></textarea>
                </div>
                <div class="mb-3">
                    <label class="form-label">Challenges Faced</label>
                    <textarea name="challenges" class="form-control" rows="4"></textarea>
                </div>
                <div class="mb-3">
                    <label class="form-label">Skills Improved</label>
                    <textarea name="skills" class="form-control" rows="3"></textarea>
                </div>
                <div class="mb-3">
                    <label class="form-label">Overall Self-Rating (1–5)</label>
                    <select name="rating" class="form-select" required>
                        <option value="">-- Select Rating --</option>
                        <option value="1">1 - Needs Improvement</option>
                        <option value="2">2 - Fair</option>
                        <option value="3">3 - Good</option>
                        <option value="4">4 - Very Good</option>
                        <option value="5">5 - Excellent</option>
                    </select>
                </div>

                <button type="submit" class="btn btn-primary">
                    <i class="bi bi-upload"></i> Submit Evaluation
                </button>
            </form>
        </div>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
