<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';
require_once '../../templates/sidebar/team_lead.php';

if (!isset($_GET['eval_id'])) {
    echo "<div class='alert alert-danger m-4'>No evaluation selected.</div>";
    require_once '../../templates/footer.php';
    exit;
}

$eval_id = $_GET['eval_id'];

// Fetch evaluation data and staff info
$stmt = $pdo->prepare("
    SELECT e.*, u.name AS staff_name, u.email
    FROM evaluations e
    JOIN users u ON e.staff_id = u.id
    WHERE e.id = ?
");
$stmt->execute([$eval_id]);
$evaluation = $stmt->fetch();

if (!$evaluation) {
    echo "<div class='alert alert-warning m-4'>Evaluation not found.</div>";
    require_once '../../templates/footer.php';
    exit;
}

// Handle POST (submit review)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $comments = trim($_POST['team_lead_comments']);
    $status = 'completed';
    $updated_at = date('Y-m-d H:i:s');

    $update = $pdo->prepare("
        UPDATE evaluations
        SET team_lead_comments = ?, team_lead_status = ?, updated_at = ?
        WHERE id = ?
    ");
    $update->execute([$comments, $status, $updated_at, $eval_id]);

    echo "<div class='alert alert-success m-4'>✅ Evaluation marked as completed.</div>";
    // Optionally redirect
}
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">📝 Evaluate: <?= htmlspecialchars($evaluation['staff_name']) ?></h3>

        <div class="card mb-4">
            <div class="card-header bg-light fw-bold">Submitted Self-Evaluation</div>
            <div class="card-body">
                <p><strong>Goals Achieved:</strong><br><?= nl2br(htmlspecialchars($evaluation['goals'])) ?></p>
                <p><strong>Challenges Faced:</strong><br><?= nl2br(htmlspecialchars($evaluation['challenges'])) ?></p>
                <p><strong>Skills Improved:</strong><br><?= nl2br(htmlspecialchars($evaluation['skills'])) ?></p>
                <p><strong>Self-Rating:</strong> <?= $evaluation['rating'] ?>/5</p>
            </div>
        </div>

        <?php if ($evaluation['team_lead_status'] === 'pending'): ?>
            <form method="POST" class="card shadow-sm p-4 border">
                <h5 class="mb-3">🗣️ Your Comments</h5>
                <div class="mb-3">
                    <textarea name="team_lead_comments" class="form-control" rows="5" required></textarea>
                </div>

                <button type="submit" class="btn btn-success">
                    <i class="bi bi-check-circle"></i> Submit Review
                </button>
            </form>
        <?php else: ?>
            <div class="alert alert-info">✅ This evaluation has already been reviewed.</div>
            <div class="card p-3">
                <h6 class="text-muted">Your Previous Comments:</h6>
                <p><?= nl2br(htmlspecialchars($evaluation['team_lead_comments'])) ?></p>
            </div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
