<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';

// Load sidebar dynamically by role
switch ($_SESSION['user']['role']) {
    case 'admin':     require_once '../../templates/sidebar/admin.php'; break;
    case 'hr':        require_once '../../templates/sidebar/hr.php'; break;
    case 'staff':     require_once '../../templates/sidebar/staff.php'; break;
    case 'team_lead': require_once '../../templates/sidebar/team_lead.php'; break;
    case 'director':  require_once '../../templates/sidebar/director.php'; break;
}

$userId = $_SESSION['user']['id'];
$successMsg = $errorMsg = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $newName = sanitizeInput($_POST['name']);
    $newPassword = $_POST['password'];
    $confirmPassword = $_POST['confirm_password'];

    if (!empty($newPassword) && $newPassword !== $confirmPassword) {
        $errorMsg = "❌ Passwords do not match.";
    } else {
        // Build SQL query
        $query = "UPDATE users SET name = ?";
        $params = [$newName];

        if (!empty($newPassword)) {
            $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);
            $query .= ", password = ?";
            $params[] = $hashedPassword;
        }

        $query .= " WHERE id = ?";
        $params[] = $userId;

        $stmt = $pdo->prepare($query);
        $stmt->execute($params);

        // Update session
        $_SESSION['user']['name'] = $newName;
        $successMsg = "✅ Profile updated successfully.";
    }
}
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">⚙️ Profile Settings</h3>

        <?php if ($successMsg): ?>
            <div class="alert alert-success"><?= $successMsg ?></div>
        <?php elseif ($errorMsg): ?>
            <div class="alert alert-danger"><?= $errorMsg ?></div>
        <?php endif; ?>

        <form method="POST" class="card shadow-sm p-4 border">
            <div class="mb-3">
                <label class="form-label">Full Name</label>
                <input type="text" name="name" class="form-control" required value="<?= htmlspecialchars($_SESSION['user']['name']) ?>">
            </div>

            <div class="mb-3">
                <label class="form-label">Email (read-only)</label>
                <input type="email" class="form-control" value="<?= htmlspecialchars($_SESSION['user']['email']) ?>" disabled>
            </div>

            <div class="mb-3">
                <label class="form-label">New Password</label>
                <input type="password" name="password" class="form-control" placeholder="Leave blank to keep current password">
            </div>

            <div class="mb-3">
                <label class="form-label">Confirm New Password</label>
                <input type="password" name="confirm_password" class="form-control" placeholder="Repeat new password">
            </div>

            <button type="submit" class="btn btn-primary">
                <i class="bi bi-save"></i> Save Changes
            </button>
        </form>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
