<?php
require_once '../../helpers/session.php';
requireLogin();
require_once '../../config/db.php';
require_once '../../helpers/functions.php';
require_once '../../templates/header.php';
require_once '../../templates/topnav.php';

// Load appropriate sidebar
switch ($_SESSION['user']['role']) {
    case 'admin':     require_once '../../templates/sidebar/admin.php'; break;
    case 'hr':        require_once '../../templates/sidebar/hr.php'; break;
    case 'director':  require_once '../../templates/sidebar/director.php'; break;
    default: exit("<div class='alert alert-danger'>Unauthorized access.</div>");
}

// Summary Queries
$totalStmt = $pdo->query("SELECT COUNT(*) FROM evaluations");
$totalEvals = $totalStmt->fetchColumn();

$staffDone = $pdo->query("SELECT COUNT(*) FROM evaluations WHERE submitted_at IS NOT NULL")->fetchColumn();
$teamLeadDone = $pdo->query("SELECT COUNT(*) FROM evaluations WHERE team_lead_status = 'completed'")->fetchColumn();
$hrDone = $pdo->query("SELECT COUNT(*) FROM evaluations WHERE hr_status = 'completed'")->fetchColumn();
$directorDone = $pdo->query("SELECT COUNT(*) FROM evaluations WHERE director_status = 'completed'")->fetchColumn();

$avgRating = $pdo->query("SELECT ROUND(AVG(rating), 2) FROM evaluations")->fetchColumn();

$gradeDist = $pdo->query("
    SELECT final_grade, COUNT(*) AS count
    FROM evaluations
    WHERE final_grade IS NOT NULL
    GROUP BY final_grade
    ORDER BY final_grade ASC
")->fetchAll(PDO::FETCH_KEY_PAIR);
?>

<div class="container-fluid">
    <div class="col p-4">
        <h3 class="mb-4">📊 Evaluation Summary Report</h3>

        <div class="row g-3 mb-4">
            <div class="col-md-3">
                <div class="card border-start border-primary border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">Total Evaluations</h6>
                        <h4><?= $totalEvals ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card border-start border-info border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">Self-Evals Submitted</h6>
                        <h4><?= $staffDone ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card border-start border-warning border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">Team Lead Completed</h6>
                        <h4><?= $teamLeadDone ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card border-start border-success border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">HR Completed</h6>
                        <h4><?= $hrDone ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card border-start border-dark border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">Director Finalized</h6>
                        <h4><?= $directorDone ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card border-start border-secondary border-4 shadow-sm">
                    <div class="card-body">
                        <h6 class="text-muted">Average Rating</h6>
                        <h4><?= $avgRating ?></h4>
                    </div>
                </div>
            </div>
        </div>

        <h5 class="mb-3">🎓 Grade Distribution</h5>
        <?php if (!empty($gradeDist)): ?>
            <table class="table table-bordered w-50">
                <thead class="table-light">
                    <tr>
                        <th>Grade</th>
                        <th>Count</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($gradeDist as $grade => $count): ?>
                        <tr>
                            <td><?= $grade ?></td>
                            <td><?= $count ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">No final grades assigned yet.</div>
        <?php endif; ?>

        <!-- Optional: PDF Export Button -->
        <a href="export_summary_pdf.php" class="btn btn-outline-secondary mt-4">
            <i class="bi bi-file-earmark-pdf"></i> Export to PDF
        </a>
    </div>
</div>

<?php require_once '../../templates/footer.php'; ?>
